clear all
set more off

/* step 1: bring in shares from removing incumbent fluctuations */
tempfile cf_emp
forv sic=1/4 {
  import excel using figures/sector_model/`sic'/pbar_emp_avg8084.xlsx, clear
  ren (A B C D E) (year2 emp_pbar emp_pt emp_st_pbar emp)
  gen sicg = `sic'
  if `sic'==1 {
    save `cf_emp', replace
	}
  else {
    append using `cf_emp'
	save `cf_emp', replace
	}
  }

* calculate counterfactual employment shares
bys year2: egen total_emp_st_pbar=total(emp_st_pbar)
bys year2: gen shr_emp_st_pbar=emp_st_pbar/total_emp_st_pbar
keep shr_emp_st_pbar year2 sicg
save `cf_emp', replace


/* step 2: calculate overall industry employment shares */
use bds_sector4, clear
keep emp sicg year2
bys year2: egen emp_tot = total(emp)
gen sector_shr = emp/emp_tot
tempfile sector_shr
save `sector_shr', replace


/* step 3: calculate industry startup employment shares */
use bds_2groups_sector4, clear
keep emp sicg ageg year2
drop if mi(ageg)

bys year2 ageg: egen empage = total(emp)
bys year2 (ageg): gen emp_tot_s = empage[1]
bys year2 sicg (ageg): gen emp_s = emp[1]
collapse (mean) emp_tot_s emp_s, by(sicg year2)
gen sector_shr_s = emp_s/emp_tot_s

* merge back in the overall industry employment share & cf employment share
merge 1:1 year2 sicg using `sector_shr', keep(match) nogen keepus(sector_shr)
merge 1:1 year2 sicg using `cf_emp', nogen


/* step 4: output data by industry to plot in matlab */
forv i=1/4 {
  outsheet year2 sector_shr_s sector_shr shr_emp_st_pbar if sicg==`i' ///
    using figures/sector_share_actual_`i'.txt, replace non nol
  }
